@@ -14,6 +14,7 @@ In addition to search requests, it provides access to term and document informat
  * :meth:`/docs <WebSearcher.docs>`
  * :meth:`/terms <WebSearcher.terms>`
  * :meth:`/update <WebSearcher.update>`
+ * :meth:`/queries <WebSearcher.queries>`
 
 WebIndexer extends WebSearcher, exposing additional resources and methods for an Indexer.
 Single documents may be added, deleted, or replaced by a unique indexed field.
@@ -39,7 +40,7 @@ CherryPy and Lucene VM integration issues:
  * Recommended that the VM ignores keyboard interrupts (-Xrs) for clean server shutdown.
 """
 
-from future_builtins import map
+from future_builtins import map, zip
 import re
 import time
 import uuid
@@ -48,13 +49,11 @@ import heapq
 import collections
 import itertools
 import os, optparse
-from email.utils import formatdate
 import contextlib
 try:
     import simplejson as json
 except ImportError:
     import json
-import warnings
 import lucene
 try:
     from org.apache.lucene import search
@@ -66,9 +65,6 @@ try:
 except ValueError:
     import engine, client
 
-if cherrypy.__version__ < '3.2':
-    warnings.warn('Support for cherrypy 3.1 will be removed in the next release.', DeprecationWarning)
-
 def tool(hook):
     "Return decorator to register tool at given hook point."
     def decorator(func):
@@ -76,53 +72,41 @@ def tool(hook):
         return func
     return decorator
 
-@tool('before_handler')
-def json_in(content_type='application/json', process_body=None):
+@tool('before_request_body')
+def json_in(process_body=None, **kwargs):
     """Handle request bodies in json format.
     
     :param content_type: request media type
     :param process_body: optional function to process body into request.params
     """
     request = cherrypy.serving.request
-    media_type = request.headers.get('content-type')
-    if media_type == content_type:
-        with HTTPError(httplib.BAD_REQUEST, ValueError, AttributeError):
-            request.json = json.load(request.body)
+    def processor(entity):
+        cherrypy.lib.jsontools.json_processor(entity)
         if process_body is not None:
             with HTTPError(httplib.BAD_REQUEST, TypeError):
                 request.params.update(process_body(request.json))
-    elif media_type:
-        message = "Expected an entity of content type {0}".format(content_type)
-        raise cherrypy.HTTPError(httplib.UNSUPPORTED_MEDIA_TYPE, message)
+    cherrypy.lib.jsontools.json_in(force='content-type' in request.headers, processor=processor, **kwargs)
 
 @tool('before_handler')
-def json_out(content_type='application/json', indent=None):
+def json_out(content_type='application/json', indent=None, **kwargs):
     """Handle responses in json format.
     
     :param content_type: response content-type header
     :param indent: indentation level for pretty printing
     """
-    request = cherrypy.serving.request
-    request._json_inner_handler = request.handler
-    headers = cherrypy.response.headers
-    headers['content-type'] = content_type
     def handler(*args, **kwargs):
-        body = request._json_inner_handler(*args, **kwargs)
-        return json.dumps(body, indent=indent) if headers['content-type'] == content_type else body
-    request.handler = handler
+        body = cherrypy.request._json_inner_handler(*args, **kwargs)
+        return json.dumps(body, indent=indent) if cherrypy.response.headers['content-type'] == content_type else body
+    cherrypy.lib.jsontools.json_out(content_type, handler=handler, **kwargs)
 
 @tool('on_start_resource')
-def allow(methods=('GET',), paths=()):
+def allow(methods=None, paths=(), **kwargs):
     "Only allow specified methods."
-    request = cherrypy.serving.request
-    if paths and hasattr(request.handler, 'args'):
+    handler = cherrypy.request.handler
+    if paths and hasattr(handler, 'args'):
         with HTTPError(httplib.NOT_FOUND, IndexError):
-            methods = paths[len(request.handler.args)]
-    if 'GET' in methods and 'HEAD' not in methods:
-        methods += 'HEAD',
-    cherrypy.response.headers['allow'] = ', '.join(methods)
-    if request.method not in methods:
-        raise cherrypy.HTTPError(httplib.METHOD_NOT_ALLOWED)
+            methods = paths[len(handler.args)]
+    cherrypy.lib.cptools.allow(methods, **kwargs)
 
 @tool('before_finalize')
 def timer():
@@ -145,13 +129,13 @@ def validate(etag=True, last_modified=False, max_age=None, expires=None):
         headers['etag'] = 'W/"{0}"'.format(root.searcher.version)
         cherrypy.lib.cptools.validate_etags()
     if last_modified:
-        headers['last-modified'] = formatdate(root.searcher.timestamp, usegmt=True)
+        headers['last-modified'] = cherrypy.lib.httputil.HTTPDate(root.searcher.timestamp)
         cherrypy.lib.cptools.validate_since()
     if max_age is not None:
         headers['age'] = int(time.time() - root.updated)
         headers['cache-control'] = 'max-age={0}'.format(max_age)
     if expires is not None:
-        headers['expires'] = formatdate(expires + root.updated, usegmt=True)
+        headers['expires'] = cherrypy.lib.httputil.HTTPDate(expires + root.updated)
 
 @tool('before_handler')
 def params(**types):
@@ -248,6 +232,7 @@ class WebSearcher(object):
             engine.IndexWriter(*directories).close()
         self.searcher = engine.MultiSearcher(directories, **kwargs) if len(directories) > 1 else engine.IndexSearcher(*directories, **kwargs)
         self.updated = time.time()
+        self.query_map = {}
     @classmethod
     def new(cls, *args, **kwargs):
         "Return new uninitialized root which can be mounted on dispatch tree before VM initialization."
@@ -258,11 +243,12 @@ class WebSearcher(object):
         self.searcher.close()
     def sync(self, host, path=''):
         "Sync with remote index."
-        path = '/' + '{0}/update/{1}/'.format(path, uuid.uuid1()).lstrip('/')
         directory = self.searcher.path
         resource = client.Resource(host)
-        names = sorted(set(resource.put(path)).difference(os.listdir(directory)))
+        response = resource.call('PUT', '/' + '{0}/update/{1}'.format(path, uuid.uuid1()).lstrip('/'))
+        names = sorted(set(response()).difference(os.listdir(directory)))
         try:
+            path = response.getheader('location') + '/'
             for name in names:
                 resource.download(path + name, os.path.join(directory, name))
         finally:
@@ -571,12 +557,60 @@ class WebSearcher(object):
             if path[1:] == ('positions',):
                 return list(searcher.positions(name, value))
         raise cherrypy.NotFound()
+    @cherrypy.expose
+    @cherrypy.tools.allow(paths=[('GET',), ('GET', 'POST'), ('GET', 'PUT', 'DELETE')])
+    def queries(self, name='', value=''):
+        """Match a document against registered queries.
+        Queries are cached by a unique name and value, suitable for document indexing.
+        
+        .. versionadded:: 1.4
+        .. note:: This interface is experimental and might change in incompatible ways in the next release.
+        
+        **GET** /queries
+            Return query set names.
+            
+            :return: [*string*,... ]
+        
+        **GET, POST** /queries/*chars*
+            Return query values and scores which match given document.
+            
+            {*string*: *string*,... }
+            
+            :return: {*string*: *number*,... }
+        
+        **GET, PUT, DELETE** /queries/*chars*/*chars*
+            Return, create, or delete a registered query.
+            
+            *string*
+            
+            :return: *string*
+        """
+        request = cherrypy.serving.request
+        if not name:
+            return sorted(self.query_map)
+        if not value:
+            if request.method == 'GET':
+                request.body.process()
+            with HTTPError(httplib.NOT_FOUND, KeyError):
+                queries = self.query_map[name]
+            scores = self.searcher.match(getattr(request, 'json', {}), *queries.values())
+            return dict(zip(queries, scores))
+        if request.method == 'DELETE':
+            return str(self.query_map.get(name, {}).pop(value, '')) or None
+        if request.method == 'PUT':
+            queries = self.query_map.setdefault(name, {})
+            if value not in queries:
+                cherrypy.response.status = httplib.CREATED
+            queries[value] = self.searcher.parse(request.json)
+        with HTTPError(httplib.NOT_FOUND, KeyError):
+            return str(self.query_map[name][value])
 
 class WebIndexer(WebSearcher):
     "Dispatch root with a delegated Indexer, exposing write methods."
     def __init__(self, *args, **kwargs):
         self.indexer = engine.Indexer(*args, **kwargs)
         self.updated = time.time()
+        self.query_map = {}
     @property
     def searcher(self):
         return self.indexer.indexSearcher
@@ -623,6 +657,8 @@ class WebIndexer(WebSearcher):
         **GET, PUT, DELETE** /update/*chars*
             Verify, create, or release unique snapshot by id of current index commit and return array of referenced filenames.
             
+            .. versionchanged:: 1.4 lucene 4.4 identifies snapshots by commit generation;  use location header
+            
             :return: [*string*,... ]
         
         **GET** /update/*chars*/*chars*
@@ -633,16 +669,30 @@ class WebIndexer(WebSearcher):
             self.updated = time.time()
             return len(self.indexer)
         method = cherrypy.request.method
-        if method == 'DELETE':
-            with HTTPError(httplib.CONFLICT, lucene.JavaError):
-                return self.indexer.policy.release(id)
-        if method == 'PUT':
-            cherrypy.response.status = httplib.CREATED
-            with HTTPError(httplib.CONFLICT, lucene.JavaError):
-                commit = self.indexer.policy.snapshot(id)
+        response = cherrypy.serving.response
+        if lucene.VERSION < '4.4':
+            if method == 'DELETE':
+                with HTTPError(httplib.CONFLICT, lucene.JavaError):
+                    return self.indexer.policy.release(id)
+            if method == 'PUT':
+                response.status = httplib.CREATED
+                response.headers['location'] = cherrypy.url(relative='server')
+                with HTTPError(httplib.CONFLICT, lucene.JavaError):
+                    commit = self.indexer.policy.snapshot(id)
+            else:
+                with HTTPError(httplib.NOT_FOUND, lucene.JavaError):
+                    commit = self.indexer.policy.getSnapshot(id)
         else:
-            with HTTPError(httplib.NOT_FOUND, lucene.JavaError):
-                commit = self.indexer.policy.getSnapshot(id)
+            if method == 'PUT':
+                commit = self.indexer.policy.snapshot()
+                response.status = httplib.CREATED
+                response.headers['location'] = cherrypy.url('/update/{0:d}'.format(commit.generation), relative='server')
+            else:
+                with HTTPError(httplib.NOT_FOUND, ValueError, AssertionError):
+                    commit = self.indexer.policy.getIndexCommit(long(id))
+                    assert commit is not None, 'commit not snapshotted'
+                if method == 'DELETE':
+                    self.indexer.policy.release(commit)
         if not name:
             return list(commit.fileNames)
         with HTTPError(httplib.NOT_FOUND, TypeError, AssertionError):
@@ -727,7 +777,7 @@ class WebIndexer(WebSearcher):
             field = self.indexer.fields[name]
         return dict((name, str(getattr(field, name))) for name in ['store', 'index', 'termvector'])
 
-def init(vmargs='-Xrs', **kwargs):
+def init(vmargs='-Xrs,-Djava.awt.headless=true', **kwargs):
     "Callback to initialize VM and app roots after daemonizing."
     lucene.initVM(vmargs=vmargs, **kwargs)
     for app in cherrypy.tree.apps.values():
