@@ -253,23 +253,25 @@ class TestCase(BaseTest):
             resource.get('/update/snapshot')
         response = resource.call('PUT', '/update/snapshot')
         assert response.status == httplib.CREATED
+        path = response.getheader('location')
         names = response()
         assert all(name.startswith('_') or name.startswith('segments_') for name in names)
-        assert resource.get('/update/snapshot') == names
+        assert resource.get(path) == names
         with assertRaises(httplib.HTTPException, httplib.NOT_FOUND):
-            resource.get('/update/snapshot/segments')
+            resource.get(path + '/segments')
         with assertRaises(httplib.HTTPException, httplib.NOT_FOUND):
-            resource.download('/update/snapshot/segments.gen', self.tempdir)
+            resource.download(path + '/segments.gen', self.tempdir)
         for name in names:
-            response = resource.call('GET', '/update/snapshot/' + name)
+            response = resource.call('GET', path + '/' + name)
             assert response and response.getheader('content-type') == 'application/x-download'
             assert len(response.body) == os.path.getsize(os.path.join(self.tempdir, name))
         assert resource.put('/update/backup') == names
-        with assertRaises(httplib.HTTPException, httplib.CONFLICT):
-            resource.put('/update/snapshot')
-        assert not resource.delete('/update/snapshot')
-        with assertRaises(httplib.HTTPException, httplib.CONFLICT):
-            resource.delete('/update/snapshot')
+        if lucene.VERSION < '4.4':
+            with assertRaises(httplib.HTTPException, httplib.CONFLICT):
+                resource.put('/update/snapshot')
+            assert not resource.delete('/update/snapshot')
+            with assertRaises(httplib.HTTPException, httplib.CONFLICT):
+                resource.delete('/update/snapshot')
         resource = client.Resource('localhost', self.ports[-1] + 1)
         with assertRaises(socket.error, errno.ECONNREFUSED):
             resource.get('/')
@@ -455,6 +457,23 @@ class TestCase(BaseTest):
         result = resource.get('/search', q='Los Angeles', group='county.city', **{'group.count': 0, 'q.field': 'county', 'q.type': 'prefix'})
         assert all(group['value'].startswith('Los Angeles') for group in result['groups'])
         assert sum(map(operator.itemgetter('count'), result['groups'])) == sum(facets.values()) == result['count']
+        assert resource.get('/queries') == []
+        with assertRaises(httplib.HTTPException, httplib.NOT_FOUND):
+            resource.get('/queries/default')
+        resource.call('PUT', '/queries/default/alpha', '*:*').status == httplib.CREATED
+        assert resource.put('/queries/default/alpha', 'name:alpha') == 'name:alpha'
+        assert resource.put('/queries/default/bravo', 'name:bravo') == 'name:bravo'
+        assert resource.get('/queries') == ['default']
+        assert resource.get('/queries/default') == {'alpha': 0.0, 'bravo': 0.0}
+        with assertRaises(httplib.HTTPException, httplib.NOT_FOUND):
+            resource.get('/queries/default/charlie')
+        queries = resource.post('/queries/default', {'name': 'alpha'})
+        assert queries['alpha'] > 0.0 and queries['bravo'] == 0.0
+        queries = resource.call('GET', '/queries/default', {'name': 'alpha bravo alpha'})()
+        assert queries['alpha'] > queries['bravo'] > 0.0
+        assert resource.delete('/queries/default/alpha') == 'name:alpha'
+        assert resource.delete('/queries/default/alpha') is None
+        assert resource.get('/queries/default') == {'bravo': 0.0}
     
     def testRealTime(self):
         "Real Time updating and searching."
